@@ -1,5 +1,5 @@
 from .store_file import store_file
-from .load_file import load_file
+from .load_file import load_file, load_file_info
 from .request_file_experimental import request_file_experimental
 from .store_file_local import store_file_local
 from .link_file import link_file
@@ -22,3 +22,4 @@ from .TemporaryDirectory import TemporaryDirectory
 from ._sha1_of_dict import sha1_of_dict
 from .encrypt_uri import encrypt_uri, decrypt_uri
 from .share_local_files_experimental import share_local_files_experimental
+from .zenodo_upload.zenodo_upload import initiate_zenodo_upload
\ No newline at end of file
