@@ -2,7 +2,7 @@ import os
 from .init import _get_client_info
 
 def get_project_id():
-    project_id = os.getenv('KACHERY_CLOUD_PROJECT_ID', '')
+    project_id = os.getenv('KACHERY_CLOUD_PROJECT', '')
     if project_id:
         return project_id
     client_info = _get_client_info()
