@@ -6,9 +6,10 @@ from kachery_cloud.get_kachery_cloud_dir import get_kachery_cloud_dir
 
 from .get_client_id import get_client_id
 from ._client_keys import _sign_message_as_client
-from ._kachery_cloud_api_url import _kachery_cloud_api_url
-from ._kacherycloud_request import _kacherycloud_request
+from ._get_kachery_gateway_url import _get_kachery_gateway_url
+from ._kachery_gateway_request import _kachery_gateway_request
 from ._get_local_client_config import _get_local_client_config
+from ._kacherycloud_request import _kacherycloud_request
 
 
 _global_init = {
@@ -23,7 +24,8 @@ def _get_client_info():
         'type': 'getClientInfo',
         'clientId': client_id
     }
-    response = _kacherycloud_request(payload)
+    response = _kachery_gateway_request(payload)
+    # response = _kacherycloud_request(payload)
     found = response['found']
     if found:
         _global_init['client_info'] = response
@@ -39,7 +41,7 @@ def init():
             'type': 'addClient'
         })
         label = socket.gethostname()
-        url = f'{_kachery_cloud_api_url}/registerClient/{client_id}?signature={signature}&label={urllib.parse.quote(label)}'
+        url = f'{_get_kachery_gateway_url()}/registerClient/{client_id}?signature={signature}&label={urllib.parse.quote(label)}'
         print('')
         print(url)
         print('')
@@ -55,21 +57,15 @@ def init():
         client_id = get_client_id()
         print('This client has already been registered.')
         print('Click the following link to configure the client:')
-        url = f'{_kachery_cloud_api_url}/client/{client_id}'
+        url = f'{_get_kachery_gateway_url()}/client/{client_id}'
         print(url)
         print('')
     client = client_info['client']
     label = client['label']
-    default_project_id = client.get('defaultProjectId', None)
     client_owner = client['ownerId']
     print(f'Client ID: {client_id}')
     print(f'Label: {label}')
     print(f'Owner: {client_owner}')
-    print(f'Default project ID: {default_project_id}')
 
-    print('')
-    print('Local configuration')
-    config = _get_local_client_config()
-    print(yaml.safe_dump(config))
     print('')
     print('* Kachery-cloud is intended for collaborative sharing of data for scientific research. It should not be used for other purposes.')
\ No newline at end of file
