@@ -1,9 +1,14 @@
 from typing import Union
 from .TaskBackend.TaskClient import TaskClient, TaskErrorException
 from .load_file import load_file
+from ._access_group_encrypt import _access_group_decrypt
 
 
 def request_file_experimental(uri: str, *, project_id: str, dest: Union[None, str]=None):
+    # important to encrypt first before requesting the file
+    if uri.startswith('sha1-enc://'):
+        uri = _access_group_decrypt(uri)
+    
     fname = load_file(uri, dest=dest)
     if fname is not None:
         return fname
